@@ -36,7 +36,6 @@ extern int insertnewtopic(struct channel *, char *, char *, int);
 extern int edittopic(struct channel *, char *, char *, int);
 extern int gettopic(struct channel *, char *);
 extern int listtopic(struct channel *, char *, int);
-extern int deltopic(struct channel *, int, char *);
 extern int deltopics(struct channel *);
 extern int swaptopic(struct channel *, int, int);
 extern int partcount(struct channel *, char *, char *);
@@ -123,9 +122,13 @@ extern int noexpiredlogons(struct channel *);
 extern int delchannelban(struct channel *, char *);
 extern int ischanopless(struct channel *);
 extern int joininprogress(void);
-extern int dbconnect(void);
-extern int dbping(void);
+extern int dbconnect(struct mysqldb *);
+extern int dbping(struct mysqldb *);
+extern int dbpingall(void);
 extern int delpermbans(struct channel *, char *, int);
+extern int getmmodecount(struct channel *);
+extern int gettimedcount(void);
+extern int deltopic(struct channel *, char *, int, char *, char *, char *);
 extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, char *, char *);
 extern struct botuser *addbotuser(char *, char *);
@@ -178,6 +181,8 @@ extern void initchannel(struct channel *);
 extern void initall(void);
 extern void initnicks(struct channel *);
 extern void initmmodes(struct channel *);
+extern void initmmodesfornick(struct channel *, char *);
+extern void changemmodesfornick(struct channel *, char *, char *);
 extern void initparts(struct channel *);
 extern void initjoins(struct channel *);
 extern void initnickbks(struct channel *);
@@ -232,3 +237,9 @@ extern void validateflags(char *, char *, int);
 extern void resetfloodcounters(struct channel *, char *);
 extern void dbclose(void);
 extern void resetcommand(struct channel *, char *, int, char *, char *, char *);
+extern void syncadmins(void);
+extern void syncusers(struct channel *);
+extern void sendadminsyncrequest(void);
+extern void sendusersyncrequest(struct channel *);
+extern void addnewsyncrequest(char *, char *);
+extern void sendsyncrequests(void);
