@@ -33,17 +33,21 @@ char *strtolower(char *);
 char *strtoupper(char *);
 int emptyline(char *);
 int iscomment(char *);
-int isnumber(char *);
 int isserver(char *);
 int isvaliduserhost(char *);
+int isvalidhost(char *);
 int isansi(char *);
 int isaction(char *);
 int isctcp(char *);
 int wordcount(char *);
 int parse(char *, int, char *, char *, int, int);
-int oer_doquery(char *, int level, const char *, ...);
+int oer_doquery(struct mysqldb *, char *, int level, const char *, ...);
 int issamenickandhost(char *, char *, char *, char *);
 int issimilarstring(char *, char *);
+int isnumbw(int, int, int);
+int completeban(char *, char *, int);
+int isinitialmysql(struct mysqldb *);
+int issamemysql(struct mysqldb *, struct mysqldb *);
 unsigned int longestword(char *);
 unsigned int isgoodquote(char *);
 void striplf(char *);
@@ -129,25 +133,41 @@ void oer_debug(int level, const char *fmt, ...)
                 va_start(ap, fmt);
 		vsnprintf(stringbuffer, WRITE_BUFFER_LENGTH, fmt, ap);
 		striplf(stringbuffer);
-		if((index(mystate->flags, (int)'o') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
-			/* do not use oer_doquery here and do not
-			   check for errors */
-			mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str_debug, stringbuffer, strlen(stringbuffer));
-			snprintf(query, WRITE_BUFFER_LENGTH, "INSERT INTO oer_output VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str_debug);
-			/* Use mysql_ping() to check that the database is alive, this is
-			   because MySQL doesn't have proper timeouts */
-			if(!mysql_ping(&mystate->mysqldb.mysqldbconn)) {
-				mysql_query(&mystate->mysqldb.mysqldbconn, query);
-			}
-		}
+		/* first output to screen, if enabled */
 		if(do_console) {
 			fprintf(stdout, "%s\n", stringbuffer);
 		}
+		/* then try to write to database */
+		if((index(mystate->flags, (int)'o') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
+			mysql_real_escape_string(&mystate->mysqldb->mysqldbconn, mysql_safe_str_debug, stringbuffer, strlen(stringbuffer));
+			snprintf(query, WRITE_BUFFER_LENGTH, "INSERT INTO oer_output VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str_debug);
+			/* only write if our connection is up or if enough
+			   time has passed, mysql_query() will rebuild the
+			   connection if needed */
+                        if(!mystate->mysqldb->isdead || (mystate->now - mystate->mysqldb->tod) > OER_MYSQL_CONNECTION_RETRY_AFTER_LOSS) {
+				if(mysql_query(&mystate->mysqldb->mysqldbconn, query)) {
+					if(do_console) {
+						fprintf(stdout, "oer_debug->mysql_query failed: %s\n", mysql_error(&mystate->mysqldb->mysqldbconn));
+					}
+					switch(mysql_errno(&mystate->mysqldb->mysqldbconn)) {
+                                        case CR_SERVER_GONE_ERROR:
+                                        case CR_SERVER_LOST:
+                                                mystate->mysqldb->isdead = 1;
+                                                mystate->mysqldb->tod = mystate->now;
+                                                break;
+                                        }
+				} else {
+					mystate->mysqldb->isdead = 0;
+					mystate->mysqldb->isalive = mystate->now;
+					mystate->mysqldb->tod = 0;
+				}
+			}
+		}
                 va_end(ap);
         }
 }
 
-int oer_doquery(char *function, int level, const char *fmt, ...)
+int oer_doquery(struct mysqldb *mysqldb, char *function, int level, const char *fmt, ...)
 {
         va_list ap;
 	struct timeval tv1;
@@ -161,26 +181,41 @@ int oer_doquery(char *function, int level, const char *fmt, ...)
 	oer_debug(level, "oer_doquery->%s\n", stringbuffer);
 #endif
 	gettimeofday(&tv1, NULL);
-	/* Use mysql_ping() to check that the database is alive, this is
-	   because MySQL doesn't have proper timeouts */
-        if(mysql_ping(&mystate->mysqldb.mysqldbconn)) {
-		return 0;
-	}
-	if(mysql_query(&mystate->mysqldb.mysqldbconn, stringbuffer)) {
+	/* only write if our connection is up or if enough
+	   time has passed, mysql_query() will rebuild the
+	   connection if needed */
+	if(!mysqldb->isdead || (mystate->now - mysqldb->tod) > OER_MYSQL_CONNECTION_RETRY_AFTER_LOSS) {
+		if(mysql_query(&mysqldb->mysqldbconn, stringbuffer)) {
 #ifdef DEBUG
-		oer_debug(OER_DEBUG_FATAL, "%s->mysql_query() failed: %s\n", function, mysql_error(&mystate->mysqldb.mysqldbconn));
+			oer_debug(OER_DEBUG_ERROR, "oer_doquery->mysql_query failed: %s\n", mysql_error(&mysqldb->mysqldbconn));
 #endif
+			switch(mysql_errno(&mysqldb->mysqldbconn)) {
+			case CR_SERVER_GONE_ERROR:
+			case CR_SERVER_LOST:
+				mysqldb->isdead = 1;
+				mysqldb->tod = mystate->now;
+				break;
+			}
+			return 0;
+		} else {
+			mysqldb->isdead = 0;
+			mysqldb->isalive = mystate->now;
+			mysqldb->tod = 0;
+		}
+	} else {
 		return 0;
 	}
 	gettimeofday(&tv2, NULL);
-	if(tv2.tv_sec == tv1.tv_sec) {
-		snprintf(stringbuffer, TXT_BUFFER, "%ld usecs", tv2.tv_usec - tv1.tv_usec);
-	} else {
-		snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
+	/* the execution time should be only output into the console otherwise
+	   we would require a second database connection for output logging */
+	if(do_console && level <= do_debug) {
+		if(tv2.tv_sec == tv1.tv_sec) {
+			snprintf(stringbuffer, TXT_BUFFER, "%ld usecs", tv2.tv_usec - tv1.tv_usec);
+		} else {
+			snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
+		}
+		fprintf(stdout, "oer_doquery->mysql_query took %s\n", stringbuffer);
 	}
-#ifdef DEBUG
-	oer_debug(level, "oer_doquery->mysql_query took %s\n", stringbuffer);
-#endif
 	return 1;
 }
 
@@ -373,19 +408,6 @@ void striplf(char *line)
 	}
 }
 
-int isnumber(char *line)
-{
-	int length;
-	int i;
-
-	for(i = 0, length = strlen(line); line[i] != '\0' && i < length; i++) {
-		if(!isdigit((int)line[i])) {
-			return 0;
-		}
-	}
-	return 1;
-}
-
 int isserver(char *line)
 {
         int i;
@@ -717,3 +739,96 @@ int issimilarstring(char *s1, char *s2)
         }
         return 0;
 }
+
+int isnumbw(int number, int low, int high)
+{
+        if(number >= low && number <= high) {
+                return 1;
+        } else {
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "isnumbw->%d is not >= %d and <= %d\n", number, low, high);
+#endif
+		return 0;
+        }
+}
+
+int isvalidhost(char *line)
+{
+        int c;
+        int c2;
+        char *ptr;
+
+	/* we require at least X.Y */
+	if(strlen(line) < 3) {
+		return 0;
+	}
+	/* we require a domain and a TLD */
+        if((ptr = index(line, '.')) == NULL) {
+                return 0;
+        }
+	/* the domain and TLD separator can't be the
+	   first nor the last character */
+        if(ptr == line || ptr == (line + (strlen(line) - 1))) {
+                return 0;
+        }
+        c = *(ptr - 1);
+        c2 = *(ptr + 1);
+	/* we want both X and Y to be printable */
+        if(!isgraph(c) || !isgraph(c2)) {
+		return 0;
+	}
+	return 1;
+}
+
+int completeban(char *from, char *to, int tlength)
+{
+        int rc;
+        char *ptr1;
+        char *ptr2;
+        char *ptr3;
+
+        ptr1 = index(from, (int)'!');
+        ptr2 = index(from, (int)'@');
+        ptr3 = index(from, (int)'.');
+        if(ptr1 == NULL && ptr2 == NULL) {
+                /* nick ban */
+                rc = snprintf(to, tlength, "%s!*@*", from);
+        } else if(ptr1 == NULL && ptr2 != NULL) {
+                /* ident@host */
+                rc = snprintf(to, tlength, "*!%s", from);
+        } else if(ptr1 == NULL && ptr2 == NULL && ptr3 != NULL) {
+                /* host.xxx */
+                rc = snprintf(to, tlength, "*!*@%s", from);
+        } else if(ptr1 != NULL && ptr2 == NULL){
+                /* nick!ident */
+                rc = snprintf(to, tlength, "%s@*", from);
+        } else {
+                /* dont know */
+                rc = snprintf(to, tlength, "%s", from);
+        }
+        return rc;
+}
+
+int isinitialmysql(struct mysqldb *mysqldb)
+{
+	if(!strlen(mysqldb->mysqldbdbhost) &&
+	   !strlen(mysqldb->mysqldbdbname) &&
+	   !strlen(mysqldb->mysqldbdbuser) &&
+	   !strlen(mysqldb->mysqldbdbpw)) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
+int issamemysql(struct mysqldb *mysqldb1, struct mysqldb *mysqldb2)
+{
+	if(!strcasecmp(mysqldb1->mysqldbdbhost, mysqldb2->mysqldbdbhost) &&
+	   !strcasecmp(mysqldb1->mysqldbdbname, mysqldb2->mysqldbdbname) &&
+	   !strcasecmp(mysqldb1->mysqldbdbuser, mysqldb2->mysqldbdbuser) &&
+	   !strcasecmp(mysqldb1->mysqldbdbpw, mysqldb2->mysqldbdbpw)) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
