@@ -49,51 +49,35 @@ void establishconnection()
                 mystate->now = time(NULL);
                 switch(serverconnection()) {
                 case OER_SERVERCONNECTION_ERR_SOCKET:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->socket() failed, exiting.\n");
-#endif
                         mystate->bailout = 1;
                         return;
 		case OER_SERVERCONNECTION_ERR_GETHOSTNAME:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostname() failed, exiting.\n");
-#endif
                         mystate->bailout = 1;
                         return;
                 case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_ERROR, "establishconnection->gethostbyname() temporary error, retrying.\n");
-#endif
                         sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
                         break;
 		case OER_SERVERCONNECTION_ERR_GETSERVER_RETRY:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_ERROR, "establishconnection->getserver() temporary error, retrying.\n");
-#endif
                         sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
                         break;
                 case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostbyname() fatal error, exiting.\n");
-#endif
                         mystate->bailout = 1;
                         return;
 		case OER_SERVERCONNECTION_ERR_BIND:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->bind() fatal error, exiting.\n");
-#endif
                         mystate->bailout = 1;
                         return;
                 case OER_SERVERCONNECTION_ERR_CONNECT_RETRY:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_ERROR, "establishconnection->connect() temporary error, retrying.\n");
-#endif
                         sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
                         break;
                 case OER_SERVERCONNECTION_ERR_CONNECT:
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_FATAL, "establishconnection->connect() fatal error, exiting.\n");
-#endif
                         mystate->bailout = 1;
                         return;
                 case OER_SERVERCONNECTION_ALREADY_CONNECTED:
@@ -129,9 +113,7 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "reconnect->%s", stringbuffer);
 #endif
 		if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "reconnect->write failed: %s\n", strerror(errno));
-#endif
 		}
 		mystate->current_server->tx += strlen(stringbuffer);
 		close(mystate->sockfd);
@@ -174,7 +156,7 @@ void reconnect()
 			oer_debug(OER_DEBUG_INFO, "reconnect->oer+MySQL exiting\n");
 #endif
 			close(mystate->sockfd);
-			mysql_close(&mystate->mysqldb.mysqldbconn);
+			mysql_close(&mystate->mysqldb->mysqldbconn);
 			exit(EXIT_SUCCESS);
 		}
 #ifdef DEBUG
@@ -213,9 +195,7 @@ int serverconnection()
 		}
 	}
 	if((mystate->sockfd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-#ifdef DEBUG
 		oer_debug(OER_DEBUG_ERROR, "serverconnection->socket() failed: %s\n", strerror(errno));
-#endif
 		return OER_SERVERCONNECTION_ERR_SOCKET;
 	}
 	memset(&servaddr, 0, sizeof(struct sockaddr_in));
@@ -223,9 +203,7 @@ int serverconnection()
 	servaddr.sin_addr.s_addr = INADDR_ANY;
 	/* get system hostname */
         if(gethostname(mystate->host, HOSTLEN) < 0) {
-#ifdef DEBUG
                 oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
-#endif
                 close(mystate->sockfd);
                 return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
         }
@@ -235,13 +213,9 @@ int serverconnection()
         }
 	if((hptr = (struct hostent *) gethostbyname(mystate->host)) == NULL) {
 #ifndef _NO_H_ERRNO
-#ifdef DEBUG
 		oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostbyname() for %s failed (h_errono = %d)\n", mystate->host, h_errno);
-#endif
 		if(h_errno == TRY_AGAIN) {
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostbyname() non-fatal error\n");
-#endif
 			close(mystate->sockfd);
 			return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY;
 		} else {
@@ -250,9 +224,7 @@ int serverconnection()
 		}
 #else
 		/* i'm feeling lucky, and lazy too :) */
-#ifdef DEBUG
 		oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostbyname() unknown error\n");
-#endif
 		close(mystate->sockfd);
 		return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY;
 #endif
@@ -261,9 +233,7 @@ int serverconnection()
 	if(strlen(mystate->vhost)) {
 		/* bind is only necessary for vhost */
 		if(bind(mystate->sockfd, (struct sockaddr *) &servaddr, sizeof(struct sockaddr)) < 0) {
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "serverconnection->bind() failed: %s (check your vhost setting)\n", strerror(errno));
-#endif
 			close(mystate->sockfd);
 			return OER_SERVERCONNECTION_ERR_BIND;
 		}
@@ -275,6 +245,7 @@ int serverconnection()
 		close(mystate->sockfd);
 		return OER_SERVERCONNECTION_ERR_GETSERVER_RETRY;
 	}
+        memset(mystate->current_server->serverhost_r, 0, HOSTLEN + 1);
 	mystate->current_server->registerconnection_start = mystate->now;
 	mystate->current_server->used = 1;
 #ifdef DEBUG
@@ -282,9 +253,7 @@ int serverconnection()
 #endif
 	if((hptr = (struct hostent *) gethostbyname(mystate->current_server->serverhost)) == NULL) {
 #ifndef _NO_H_ERRNO
-#ifdef DEBUG
 		oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostbyname() for %s failed (h_errno = %d)\n", mystate->current_server->serverhost, h_errno);
-#endif
 		if(h_errno == NO_ADDRESS || h_errno == HOST_NOT_FOUND || h_errno == TRY_AGAIN) {
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "serverconnection->switching to next server if available\n");
@@ -294,9 +263,7 @@ int serverconnection()
 		}
 #else
 		/* i'm feeling lucky, and lazy too :) */
-#ifdef DEBUG
 		oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostbyname() unknown error\n");
-#endif
 		close(mystate->sockfd);
 		return OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY;
 #endif
@@ -304,9 +271,7 @@ int serverconnection()
 	memcpy(&servaddr.sin_addr, hptr->h_addr_list[0], sizeof(struct in_addr));
 	servaddr.sin_port = htons(mystate->current_server->serverport);
 	if(connect(mystate->sockfd, (struct sockaddr *) &servaddr, sizeof(struct sockaddr_in)) < 0) {
-#ifdef DEBUG
-		oer_debug(OER_DEBUG_ERROR, "serverconnection->connect() failed: %s\n", strerror(errno));
-#endif
+		oer_debug(OER_DEBUG_ERROR, "serverconnection->connect() failed: %s (%d)\n", strerror(errno), errno);
 		if(errno == ECONNREFUSED || errno == ETIMEDOUT || errno == ENETUNREACH || errno == EHOSTUNREACH) {
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "serverconnection->connect() non-fatal error\n");
@@ -366,9 +331,7 @@ int registerconnection()
                         oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 #endif
                         if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
                                 oer_debug(OER_DEBUG_ERROR, "registerconnection->write failed: %s\n", strerror(errno));
-#endif
                                 return OER_REGISTERCONNECTION_ERR_WRITE;
                         }
                         mystate->current_server->tx += strlen(stringbuffer);
@@ -382,9 +345,7 @@ int registerconnection()
                 oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 #endif
                 if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_ERROR, "registerconnection->write failed: %s\n", strerror(errno));
-#endif
                         return OER_REGISTERCONNECTION_ERR_WRITE;
                 }
                 mystate->current_server->tx += strlen(stringbuffer);
@@ -410,9 +371,7 @@ int registerconnection()
                 oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 #endif
                 if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
                         oer_debug(OER_DEBUG_ERROR, "registerconnection->write failed: %s\n", strerror(errno));
-#endif
                         return OER_REGISTERCONNECTION_ERR_WRITE;
                 }
                 mystate->current_server->tx += strlen(stringbuffer);
@@ -438,9 +397,7 @@ int handleserverdata()
         do {
                 if((br = read(mystate->sockfd, &ch, 1)) < 0) {
 			/* error while reading from server socket */
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "handleserverdata->read failed: %s\n", strerror(errno));
-#endif
 			return OER_HANDLESERVERDATA_ERR_READ;
                 } else if(br == 0) {
 			/* nothing or EOF was returned, bail out */
@@ -466,8 +423,8 @@ int handleserverdata()
 	/* here we log all the server traffic, prefix with timestamp */
 	if((index(mystate->flags, (int)'l') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
 		/* it doesn't matter if logging fails */
-		mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str1, stringbuffer, strlen(stringbuffer));
-		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO oer_raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
+		mysql_real_escape_string(&mystate->mysqldb->mysqldbconn, mysql_safe_str1, stringbuffer, strlen(stringbuffer));
+		oer_doquery(mystate->mysqldb, "handleserverdata", OER_DEBUG_NOISE, "INSERT INTO oer_raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
 	}
 	if((ptr = (char *) strstr(stringbuffer, "PING :")) != NULL) {
 		snprintf(pong, STRINGLEN, "PONG :%s\n", ptr + 6);
@@ -475,9 +432,7 @@ int handleserverdata()
 		oer_debug(OER_DEBUG_INFO, "handleserverdata->%s", pong);
 #endif
 		if(write(mystate->sockfd, pong, strlen(pong)) < 0) {
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "handleserverdata->write failed: %s\n", strerror(errno));
-#endif
 			return OER_HANDLESERVERDATA_ERR_WRITE;
 		}
 		mystate->current_server->tx += strlen(pong);
@@ -549,9 +504,7 @@ int processtimeds()
                         oer_debug(OER_DEBUG_INFO, "processtimeds->%s", stringbuffer);
 #endif
                         if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
                                 oer_debug(OER_DEBUG_ERROR, "processtimeds->write failed: %s\n", strerror(errno));
-#endif
                                 return OER_PROCESSTIMEDS_ERR_WRITE;
                         }
                         mystate->current_server->tx += strlen(stringbuffer);
@@ -642,9 +595,7 @@ void proxysetup()
 		oer_debug(OER_DEBUG_INFO, "proxysetup->%s", stringbuffer);
 #endif
 		if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
-#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "proxysetup->write failed: %s\n", strerror(errno));
-#endif
 		}
 	}
 }
