@@ -71,7 +71,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 #include <sys/wait.h>
+
 #include <mysql.h>
+#include <mysql/errmsg.h>
 
 enum NTHMODE_RETURN_VALUES {
 	OER_NTHMODE_OP,
@@ -171,6 +173,8 @@ enum WHICHCOMMAND_RETURN_VALUES {
         OER_WHICHCOMMAND_DBCLOSE,
         OER_WHICHCOMMAND_DBCONNECT,	
         OER_WHICHCOMMAND_RESET,
+        OER_WHICHCOMMAND_CHANINFO,
+        OER_WHICHCOMMAND_QUEUESTATS,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -262,7 +266,7 @@ enum OER_FLAGS_TYPE {
         OER_FLAGS_TYPE_USER
 };
 
-#define OER_FLAGS_GLOBAL "dfglmnopqs"
+#define OER_FLAGS_GLOBAL "dfglmnopqsS"
 #define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
 #define OER_FLAGS_USER "!adfmnovrsx"
@@ -272,6 +276,52 @@ enum OER_FLAGS_TYPE {
 /* from glib.h */
 #define ABS(a)         (((a) < 0) ? -(a) : (a))
 
+#define OER_LIMIT_SERVER_PORT_MIN 1
+#define OER_LIMIT_SERVER_PORT_MAX 65536
+#define OER_LIMIT_SERVER_MODES_MIN 1
+#define OER_LIMIT_SERVER_MODES_MAX 6
+#define OER_LIMIT_SERVER_PING_MIN 10
+#define OER_LIMIT_SERVER_PING_MAX 86400
+#define OER_LIMIT_SERVER_PROTOPER_MIN 0
+#define OER_LIMIT_SERVER_PROTOPER_MAX 1
+#define OER_LIMIT_BANVARS_AUTOREJOIN_MIN 0
+#define OER_LIMIT_BANVARS_AUTOREJOIN_MAX 86400
+#define OER_LIMIT_BANVARS_PARTREJOIN_MIN 0
+#define OER_LIMIT_BANVARS_PARTREJOIN_MAX 86400
+#define OER_LIMIT_BANVARS_PUBLICFLOOD_MIN 0
+#define OER_LIMIT_BANVARS_PUBLICFLOOD_MAX 86400
+#define OER_LIMIT_BANVARS_PUBLICFLOODREPEAT_MIN 0
+#define OER_LIMIT_BANVARS_PUBLICFLOODREPEAT_MAX 86400
+#define OER_LIMIT_BANVARS_BADWORD_MIN 0
+#define OER_LIMIT_BANVARS_BADWORD_MAX 86400
+#define OER_LIMIT_BANVARS_BADNICK_MIN 0
+#define OER_LIMIT_BANVARS_BADNICK_MAX 86400
+#define OER_LIMIT_BANVARS_NORMALBAN_MIN 0
+#define OER_LIMIT_BANVARS_NORMALBAN_MAX 86400
+#define OER_LIMIT_CHANNEL_CHANLIMIT_MIN 1
+#define OER_LIMIT_CHANNEL_CHANLIMIT_MAX 99999
+#define OER_LIMIT_FLOODVARS_REPEAT_EXPIRE_MIN 1
+#define OER_LIMIT_FLOODVARS_REPEAT_EXPIRE_MAX 86400
+#define OER_LIMIT_FLOODVARS_REPEAT_LIMIT_MIN 1
+#define OER_LIMIT_FLOODVARS_REPEAT_LIMIT_MAX 1000
+#define OER_LIMIT_FLOODVARS_INTERVAL_MIN 1
+#define OER_LIMIT_FLOODVARS_INTERVAL_MAX 86400
+#define OER_LIMIT_FLOODVARS_LINES_MIN 1
+#define OER_LIMIT_FLOODVARS_LINES_MAX 1000
+#define OER_LIMIT_FLOODVARS_CHARS_MIN 1
+#define OER_LIMIT_FLOODVARS_CHARS_MAX 100000
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_EXPIRE_MIN 1
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_EXPIRE_MAX 86400
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_LIMIT_MIN 1
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_LIMIT_MAX 1000
+#define OER_LIMIT_LISTCOMMAND_STARTPOS_MIN 1
+#define OER_LIMIT_LISTCOMMAND_STARTPOS_MAX 1000
+#define OER_LIMIT_TOPICS_MIN 1
+#define OER_LIMIT_TOPICS_MAX OER_TOPICS
+#define OER_LIMIT_SHOWLAST_MIN 1
+#define OER_LIMIT_SHOWLAST_MAX OER_LAST_MAX
+#define OER_LIMIT_SHOWSEEN_MIN 1
+#define OER_LIMIT_SHOWSEEN_MAX OER_SEEN_MAX
 #define MYSQL_BANNED_CHARS "/.#-"
 #define OER_MAINLOOP_TIMEOUT_SECS 1
 #define OER_MAINLOOP_TIMEOUT_USECS 0
@@ -299,13 +349,15 @@ enum OER_FLAGS_TYPE {
 #define OER_DELAY_BETWEEN_RECORD_CHECKS 120
 #define OER_AUTO_REJOIN_TIME 3
 #define OER_QUOTE_INTERVAL 300
+#define OER_ADVERT_INTERVAL 300
+#define OER_Q_QUERY_INTERVAL 10
 #define OER_ALLOWED_PARTS OER_PARTS / 5
 #define OER_RECONNECT_DELAY 30
 #define OER_NETJOIN_DELAY 15
 #define OER_PUBMSGS 20
 #define OER_NICKCHANGES 20
 #define OER_SERVER_IS_STONED_FOR 300
-#define OER_LINENOISE_INTERVAL_MIN 1
+#define OER_LINENOISE_INTERVAL_MIN 0
 #define OER_MASSMODE_LIMIT 3
 #define OER_LAST 3
 #define OER_LAST_MAX 10
@@ -313,13 +365,15 @@ enum OER_FLAGS_TYPE {
 #define OER_SEEN 3
 #define OER_SEEN_MAX 10
 #define OER_TOPICS 20
-#define OER_TOPICLEN 160
+#define OER_TOPICLEN 250
 #define TOPIC_SEPARATOR " | "
 #define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
 #define OER_REGISTERCONNECTION_TIMEOUT 600
 #define OER_MYSQL_CONNECTION_RETRY 60
+#define OER_MYSQL_CONNECTION_RETRY_AFTER_LOSS 1800
+#define OER_MYSQL_TIMESTAMP_CHECK_INTERVAL 300
 #define OER_BANVARS_AUTO_REJOIN 30
 #define OER_BANVARS_PART_REJOIN 600
 #define OER_BANVARS_PUBLIC_FLOOD 300
@@ -369,7 +423,7 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org"
 #define OER_UNKNOWN "unknown"
-#define OER_VERSION "oer+MySQL version 1.0-37"
+#define OER_VERSION "oer+MySQL version 1.0-40"
 #define OER_COPYRIGHT1 "Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
@@ -377,7 +431,9 @@ This is free software, and you are welcome to redistribute it under\n\
 certain conditions; again see COPYING for details.\n"
 
 struct mysqldb {
+	int isdead;
 	time_t isalive;
+	time_t tod;
         char mysqldbdbhost[HOSTLEN + 1];
         char mysqldbdbname[TINYSTRINGLEN + 1];
         char mysqldbdbuser[TINYSTRINGLEN + 1];
@@ -417,6 +473,8 @@ struct locked {
 
 struct qauth {
 	int hasauth;
+	int isonline;
+	time_t lastquery;
 	int authed;
 	char q[USERHOSTLEN + 1];
 	char name[NICKLEN + 1];
@@ -544,8 +602,16 @@ struct channelban {
         struct channelban *prev;
 };
 
+struct syncrequest {
+	char target[CHANLEN + 1];
+	char nick[NICKLEN + 1];
+	struct syncrequest *next;
+	struct syncrequest *prev;
+};
+
 struct server {
 	char serverhost[HOSTLEN + 1];
+	char serverhost_r[HOSTLEN + 1];
 	int serverport;
 	int servermodes;
 	int pingfrequency;
@@ -585,6 +651,7 @@ struct channel {
 	int requestop_now;
 	time_t rejoin_at;
 	time_t last_quote;
+	time_t last_advert;
 	time_t join_ts;
 	time_t userts;
 	time_t userauthedsts;
@@ -609,7 +676,7 @@ struct channel {
 };
 
 struct state {
-	char config[TINYSTRINGLEN + 1];
+	char config[STRINGLEN + 1];
 	/* this is our current nick, might be temporarily set
 	to getnick when attempting to change nick */
         char nick[NICKLEN + 1];
@@ -624,7 +691,7 @@ struct state {
 	char flags[FLAGLEN + 1];
 	char ident[IDENTLEN + 1];
 	char adminsfrom[IDENTLEN + 1];
-	char usersfrom[IDENTLEN + 1];
+        char usersfrom[IDENTLEN + 1];
 	char prefix[TINYSTRINGLEN + 1];
 	char state[STRINGLEN + 1];
 	char proxysetup[STRINGLEN + 1];
@@ -656,6 +723,9 @@ struct state {
 	struct server *servers;
 	struct server *current_server;
 	struct timed *timeds;
-        struct mysqldb mysqldb;
+        struct syncrequest *syncs;
+        struct mysqldb *mysqldb;
+        struct mysqldb *mysqladmins;
+        struct mysqldb *mysqlusers;
 	struct last_action last_action;
 };
