@@ -61,7 +61,7 @@ int main(int argc, char *argv[])
 #ifdef HAVE_LOCALE_H
         char *locptr;
 #endif
-	char config[TINYSTRINGLEN + 1];
+	char config[STRINGLEN + 1];
         char adminsfrom[IDENTLEN + 1];
         char usersfrom[IDENTLEN + 1];
         char state[STRINGLEN + 1];
@@ -89,14 +89,14 @@ int main(int argc, char *argv[])
 	do_adminsfrom = 0;
 	do_usersfrom = 0;
 	do_state = 0;
-	strncpy(config, "oer+MySQL.conf", TINYSTRINGLEN);
+	strncpy(config, "oer+MySQL.conf", STRINGLEN);
         while((c = getopt(argc, argv, "a:cd:f:hsu:t:v")) > 0) {
 		switch(c) {
 		case 'a':
 			strncpy(adminsfrom, optarg, IDENTLEN);
-			oer_debug(OER_DEBUG_INFO, "main->I will get my admins with ident %s\n", adminsfrom);
-			do_adminsfrom = 1;
-			break;
+                        oer_debug(OER_DEBUG_INFO, "main->I will get my admins with ident %s\n", adminsfrom);
+                        do_adminsfrom = 1;
+                        break;
 		case 'c':
 			do_console = 1;
 			break;
@@ -104,7 +104,7 @@ int main(int argc, char *argv[])
 			do_debug = atoi(optarg);
 			break;
 		case 'f':
-			strncpy(config, optarg, TINYSTRINGLEN);
+			strncpy(config, optarg, STRINGLEN);
 			break;
 		case 'h':
 			do_help = 1;
@@ -114,9 +114,9 @@ int main(int argc, char *argv[])
 			break;
 		case 'u':
 			strncpy(usersfrom, optarg, IDENTLEN);
-			oer_debug(OER_DEBUG_INFO, "main->I will get my users with ident %s\n", usersfrom);
-			do_usersfrom = 1;
-			break;
+                        oer_debug(OER_DEBUG_INFO, "main->I will get my users with ident %s\n", usersfrom);
+                        do_usersfrom = 1;
+                        break;
 		case 't':
 			strncpy(state, optarg, STRINGLEN);
 			oer_debug(OER_DEBUG_INFO, "main->my state is %s\n", state);
@@ -183,30 +183,49 @@ int main(int argc, char *argv[])
         }
 #endif
 	if((mystate = emptystate()) == NULL) {
-		oer_debug(OER_DEBUG_FATAL, "main->failed to allocate memory for irc state\n");
+		oer_debug(OER_DEBUG_FATAL, "main->failed to allocate memory for oer+MySQL main state\n");
 		exit(EXIT_FAILURE);
 	}
-	strcpy(mystate->config, config);
-	if(do_adminsfrom) {
-		strcpy(mystate->adminsfrom, adminsfrom);
-	}
-	if(do_usersfrom) {
-		strcpy(mystate->usersfrom, usersfrom);
-	}
+	strncpy(mystate->config, config, STRINGLEN);
 	if(do_state) {
 		strcpy(mystate->state, state);
 	}
+	if(do_adminsfrom) {
+                strcpy(mystate->adminsfrom, adminsfrom);
+        }
+        if(do_usersfrom) {
+                strcpy(mystate->usersfrom, usersfrom);
+        }
 	if(!loadconf(mystate->config)) {
                 oer_debug(OER_DEBUG_FATAL, "main->loadconf() failed\n");
 		exit(EXIT_FAILURE);
         }
-	if(!dbconnect()) {
+	/* free mystate->mysqladmins if not needed */
+	if(isinitialmysql(mystate->mysqladmins) || issamemysql(mystate->mysqladmins, mystate->mysqldb)) {
+		free(mystate->mysqladmins);
+		mystate->mysqladmins = mystate->mysqldb;
+	}
+	/* free mystate->mysqlusers if not needed */
+	if(isinitialmysql(mystate->mysqlusers) || issamemysql(mystate->mysqlusers, mystate->mysqldb)) {
+		free(mystate->mysqlusers);
+		mystate->mysqlusers = mystate->mysqldb;
+	}
+	if(!dbconnect(mystate->mysqldb)) {
 		exit(EXIT_FAILURE);
         }
-	if(!dbping()) {
-		exit(EXIT_FAILURE);
+	mystate->mysqldb->isalive = time(NULL);
+	if(mystate->mysqladmins != mystate->mysqldb) {
+		if(!dbconnect(mystate->mysqladmins)) {
+			exit(EXIT_FAILURE);
+		}
+		mystate->mysqladmins->isalive = time(NULL);
+	}
+	if(mystate->mysqlusers != mystate->mysqldb) {
+		if(!dbconnect(mystate->mysqlusers)) {
+			exit(EXIT_FAILURE);
+		}
+		mystate->mysqlusers->isalive = time(NULL);
 	}
-	mystate->mysqldb.isalive = time(NULL);
         if(do_console) {
 		oer_debug(OER_DEBUG_INFO, "console mode is on (debug messages will be shown on screen)\n");
 	}
@@ -260,10 +279,8 @@ int main(int argc, char *argv[])
 		retval = select(mystate->sockfd + 1, &rsock, NULL, NULL, &tv);
                 mystate->now = time(NULL);
 		if(retval < 0) {
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "main->select() failed: %s\n", strerror(errno));
-#endif
 			if(errno != EINTR) {
+				oer_debug(OER_DEBUG_ERROR, "main->select() failed: %s\n", strerror(errno));
 				mystate->reconnect = OER_RECONNECT_ERROR;
 				reconnect();
 			}
@@ -308,7 +325,7 @@ int main(int argc, char *argv[])
                         break;
                 }
 	}
-        mysql_close(&mystate->mysqldb.mysqldbconn);
+        mysql_close(&mystate->mysqldb->mysqldbconn);
 	exit(EXIT_SUCCESS);
 }
 
