@@ -24,6 +24,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 /* global prototype definitions */
+extern int checkauth(struct channel *, char *, char *, int, int);
 extern void parseirc(char *);
 extern void parsemsg(char *, char *, char *, char *);
+extern void parsenotice(char *, char *, char *, char *);
 extern void parsecommand(char *, char *, char *, char *);
