@@ -18,7 +18,7 @@ if ($args != 2) {
 $arg1 = @ARGV[0];
 $arg2 = @ARGV[1];
 
-print "UPDATE admins SET ident = '$arg2' WHERE ident = '$arg1';\n";
-print "UPDATE hostmasks SET ident = '$arg2' WHERE type = 1 AND ident = '$arg1';\n";
-print "UPDATE passwords SET ident = '$arg2' WHERE type = 2 AND ident = '$arg1';\n";
-print "UPDATE timestamps SET twhen = twhen + 1 WHERE ttype = 'admins' WHERE ident = '$arg2';\n";
+print "UPDATE oer_admins SET ident = '$arg2' WHERE ident = '$arg1';\n";
+print "UPDATE oer_hostmasks SET ident = '$arg2' WHERE type = 1 AND ident = '$arg1';\n";
+print "UPDATE oer_passwords SET ident = '$arg2' WHERE type = 2 AND ident = '$arg1';\n";
+print "UPDATE oer_timestamps SET twhen = twhen + 1 WHERE ttype = 'admins' WHERE ident = '$arg2';\n";
